[][src]Trait style::values::computed::ToComputedValue

pub trait ToComputedValue {
    type ComputedValue;
    fn to_computed_value(&self, context: &Context) -> Self::ComputedValue;
fn from_computed_value(computed: &Self::ComputedValue) -> Self; }

A trait to represent the conversion between computed and specified values.

This trait is derivable with #[derive(ToComputedValue)]. The derived implementation just calls ToComputedValue::to_computed_value on each field of the passed value. The deriving code assumes that if the type isn't generic, then the trait can be implemented as simple Clone::clone calls, this means that a manual implementation with ComputedValue = Self is bogus if it returns anything else than a clone.

Associated Types

type ComputedValue

The computed value type we're going to be converted to.

Loading content...

Required methods

fn to_computed_value(&self, context: &Context) -> Self::ComputedValue

Convert a specified value to a computed value, using itself and the data inside the Context.

fn from_computed_value(computed: &Self::ComputedValue) -> Self

Convert a computed value to specified value form.

This will be used for recascading during animation. Such from_computed_valued values should recompute to the same value.

Loading content...

Implementations on Foreign Types

impl<A, B> ToComputedValue for (A, B) where
    A: ToComputedValue,
    B: ToComputedValue
[src]

type ComputedValue = (<A as ToComputedValue>::ComputedValue, <B as ToComputedValue>::ComputedValue)

impl<T> ToComputedValue for Option<T> where
    T: ToComputedValue
[src]

type ComputedValue = Option<<T as ToComputedValue>::ComputedValue>

impl<T> ToComputedValue for Size2D<T> where
    T: ToComputedValue
[src]

type ComputedValue = Size2D<<T as ToComputedValue>::ComputedValue>

impl<T> ToComputedValue for Vec<T> where
    T: ToComputedValue
[src]

type ComputedValue = Vec<<T as ToComputedValue>::ComputedValue>

impl<T> ToComputedValue for Box<T> where
    T: ToComputedValue
[src]

type ComputedValue = Box<<T as ToComputedValue>::ComputedValue>

impl<T> ToComputedValue for Box<[T]> where
    T: ToComputedValue
[src]

type ComputedValue = Box<[<T as ToComputedValue>::ComputedValue]>

impl ToComputedValue for ()[src]

type ComputedValue = ()

impl ToComputedValue for bool[src]

type ComputedValue = bool

impl ToComputedValue for f32[src]

type ComputedValue = f32

impl ToComputedValue for i32[src]

type ComputedValue = i32

impl ToComputedValue for u8[src]

type ComputedValue = u8

impl ToComputedValue for u16[src]

type ComputedValue = u16

impl ToComputedValue for u32[src]

type ComputedValue = u32

impl ToComputedValue for usize[src]

type ComputedValue = usize

impl ToComputedValue for String[src]

type ComputedValue = String

impl ToComputedValue for Box<str>[src]

type ComputedValue = Box<str>

impl ToComputedValue for AllowedNumericType[src]

type ComputedValue = AllowedNumericType

Loading content...

Implementors

impl ToComputedValue for Symbol where
    OwnedStr: ToComputedValue<ComputedValue = OwnedStr>,
    CustomIdent: ToComputedValue<ComputedValue = CustomIdent>, 
[src]

type ComputedValue = Symbol

impl ToComputedValue for FontDisplay[src]

impl ToComputedValue for LonghandId[src]

impl ToComputedValue for ShorthandId[src]

impl ToComputedValue for style::properties::longhands::_servo_overflow_clip_box::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::_servo_top_layer::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::align_content::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::align_items::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::align_self::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::animation_direction::single_value::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::animation_fill_mode::single_value::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::animation_play_state::single_value::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::backface_visibility::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::background_attachment::single_value::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::background_clip::single_value::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::background_origin::single_value::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::border_collapse::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::box_sizing::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::caption_side::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::direction::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::empty_cells::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::flex_direction::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::flex_wrap::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::font_variant_caps::SpecifiedValue[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::image_rendering::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::justify_content::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::list_style_position::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::list_style_type::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::mix_blend_mode::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::pointer_events::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::position::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::table_layout::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::text_justify::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::text_rendering::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::unicode_bidi::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::visibility::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::white_space::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::writing_mode::computed_value::T[src]

type ComputedValue = T

impl ToComputedValue for FontFamilyNameSyntax[src]

impl ToComputedValue for GenericFontFamily[src]

impl ToComputedValue for SingleFontFamily where
    FamilyName: ToComputedValue<ComputedValue = FamilyName>,
    GenericFontFamily: ToComputedValue<ComputedValue = GenericFontFamily>, 
[src]

impl ToComputedValue for ExtremumLength[src]

impl ToComputedValue for Impossible[src]

impl ToComputedValue for KeyframesName where
    CustomIdent: ToComputedValue<ComputedValue = CustomIdent>,
    Atom: ToComputedValue<ComputedValue = Atom>, 
[src]

impl ToComputedValue for FillRule[src]

impl ToComputedValue for ShapeBox[src]

impl ToComputedValue for ShapeGeometryBox where
    ShapeBox: ToComputedValue<ComputedValue = ShapeBox>, 
[src]

impl ToComputedValue for VerticalAlignKeyword[src]

impl ToComputedValue for StepPosition[src]

impl ToComputedValue for TimingKeyword[src]

impl ToComputedValue for CounterStyle where
    CustomIdent: ToComputedValue<ComputedValue = CustomIdent>,
    SymbolsType: ToComputedValue<ComputedValue = SymbolsType>,
    Symbols: ToComputedValue<ComputedValue = Symbols>, 
[src]

impl ToComputedValue for SymbolsType[src]

impl ToComputedValue for GradientCompatMode[src]

impl ToComputedValue for ShapeExtent[src]

impl ToComputedValue for RaySize[src]

type ComputedValue = RaySize

impl ToComputedValue for TransformStyle[src]

impl ToComputedValue for BackgroundRepeatKeyword[src]

impl ToComputedValue for BorderImageRepeatKeyword[src]

impl ToComputedValue for BorderSideWidth[src]

impl ToComputedValue for BorderStyle[src]

impl ToComputedValue for Appearance[src]

impl ToComputedValue for BreakBetween[src]

impl ToComputedValue for BreakWithin[src]

impl ToComputedValue for SpecifiedClear[src]

impl ToComputedValue for SpecifiedFloat[src]

impl ToComputedValue for Overflow[src]

impl ToComputedValue for OverflowAnchor[src]

impl ToComputedValue for OverflowClipBox[src]

impl ToComputedValue for OverscrollBehavior[src]

impl ToComputedValue for Resize[src]

impl ToComputedValue for ScrollSnapAlignKeyword[src]

impl ToComputedValue for ScrollSnapAxis[src]

impl ToComputedValue for ScrollSnapStrictness[src]

impl ToComputedValue for TransitionProperty where
    ShorthandId: ToComputedValue<ComputedValue = ShorthandId>,
    LonghandId: ToComputedValue<ComputedValue = LonghandId>,
    CustomPropertyName: ToComputedValue<ComputedValue = CustomPropertyName>,
    CustomIdent: ToComputedValue<ComputedValue = CustomIdent>, 
[src]

impl ToComputedValue for Color[src]

impl ToComputedValue for AngleOrPercentage[src]

impl ToComputedValue for NumberOrPercentage[src]

impl ToComputedValue for style::values::specified::font::FontFamily[src]

impl ToComputedValue for FontFeatureSettings[src]

impl ToComputedValue for FontLanguageOverride[src]

impl ToComputedValue for FontSize[src]

impl ToComputedValue for FontSizeAdjust[src]

impl ToComputedValue for FontSizeKeyword[src]

impl ToComputedValue for FontStretch[src]

type ComputedValue = FontStretch

impl ToComputedValue for FontStyle[src]

type ComputedValue = FontStyle

impl ToComputedValue for FontVariantAlternates[src]

impl ToComputedValue for FontVariantEastAsian[src]

impl ToComputedValue for FontVariantLigatures[src]

impl ToComputedValue for FontVariantNumeric[src]

impl ToComputedValue for FontVariationSettings[src]

impl ToComputedValue for FontWeight[src]

impl ToComputedValue for SpecifiedLineDirection[src]

type ComputedValue = LineDirection

impl ToComputedValue for MozImageRect[src]

impl ToComputedValue for AbsoluteLength[src]

impl ToComputedValue for Length[src]

type ComputedValue = Length

impl ToComputedValue for LengthPercentage[src]

impl ToComputedValue for NoCalcLength[src]

type ComputedValue = Length

impl ToComputedValue for MozListReversed[src]

impl ToComputedValue for Quotes where
    QuoteList: ToComputedValue<ComputedValue = QuoteList>, 
[src]

type ComputedValue = Quotes

impl ToComputedValue for OutlineStyle where
    BorderStyle: ToComputedValue<ComputedValue = BorderStyle>, 
[src]

impl ToComputedValue for GridTemplateAreas where
    TemplateAreasArc: ToComputedValue<ComputedValue = TemplateAreasArc>, 
[src]

impl ToComputedValue for HorizontalPositionKeyword[src]

impl ToComputedValue for MasonryItemOrder[src]

impl ToComputedValue for MasonryPlacement[src]

impl ToComputedValue for VerticalPositionKeyword[src]

impl ToComputedValue for Resolution[src]

impl ToComputedValue for IsAbsolute[src]

impl ToComputedValue for PathCommand where
    CoordPair: ToComputedValue<ComputedValue = CoordPair>,
    IsAbsolute: ToComputedValue<ComputedValue = IsAbsolute>,
    CoordPair: ToComputedValue<ComputedValue = CoordPair>,
    IsAbsolute: ToComputedValue<ComputedValue = IsAbsolute>,
    CSSFloat: ToComputedValue<ComputedValue = CSSFloat>,
    IsAbsolute: ToComputedValue<ComputedValue = IsAbsolute>,
    CSSFloat: ToComputedValue<ComputedValue = CSSFloat>,
    IsAbsolute: ToComputedValue<ComputedValue = IsAbsolute>,
    CoordPair: ToComputedValue<ComputedValue = CoordPair>,
    CoordPair: ToComputedValue<ComputedValue = CoordPair>,
    CoordPair: ToComputedValue<ComputedValue = CoordPair>,
    IsAbsolute: ToComputedValue<ComputedValue = IsAbsolute>,
    CoordPair: ToComputedValue<ComputedValue = CoordPair>,
    CoordPair: ToComputedValue<ComputedValue = CoordPair>,
    IsAbsolute: ToComputedValue<ComputedValue = IsAbsolute>,
    CoordPair: ToComputedValue<ComputedValue = CoordPair>,
    CoordPair: ToComputedValue<ComputedValue = CoordPair>,
    IsAbsolute: ToComputedValue<ComputedValue = IsAbsolute>,
    CoordPair: ToComputedValue<ComputedValue = CoordPair>,
    IsAbsolute: ToComputedValue<ComputedValue = IsAbsolute>,
    CSSFloat: ToComputedValue<ComputedValue = CSSFloat>,
    CSSFloat: ToComputedValue<ComputedValue = CSSFloat>,
    CSSFloat: ToComputedValue<ComputedValue = CSSFloat>,
    ArcFlag: ToComputedValue<ComputedValue = ArcFlag>,
    ArcFlag: ToComputedValue<ComputedValue = ArcFlag>,
    CoordPair: ToComputedValue<ComputedValue = CoordPair>,
    IsAbsolute: ToComputedValue<ComputedValue = IsAbsolute>, 
[src]

impl ToComputedValue for LineBreak[src]

impl ToComputedValue for OverflowWrap[src]

impl ToComputedValue for TextAlign[src]

impl ToComputedValue for TextAlignKeyword[src]

impl ToComputedValue for TextAlignLast[src]

impl ToComputedValue for TextDecorationSkipInk[src]

impl ToComputedValue for TextEmphasisFillMode[src]

impl ToComputedValue for TextEmphasisHorizontalWritingModeValue[src]

impl ToComputedValue for TextEmphasisShapeKeyword[src]

impl ToComputedValue for TextEmphasisStyle[src]

impl ToComputedValue for TextEmphasisVerticalWritingModeValue[src]

impl ToComputedValue for TextOverflowSide where
    OwnedStr: ToComputedValue<ComputedValue = OwnedStr>, 
[src]

impl ToComputedValue for TextTransformCase[src]

impl ToComputedValue for WordBreak[src]

impl ToComputedValue for CursorKind[src]

impl ToComputedValue for UserSelect[src]

impl ToComputedValue for Symbols where
    OwnedSlice<Symbol>: ToComputedValue<ComputedValue = OwnedSlice<Symbol>>, 
[src]

type ComputedValue = Symbols

impl ToComputedValue for style::properties::longhands::animation_delay::SpecifiedValue[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::animation_direction::SpecifiedValue[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::animation_duration::SpecifiedValue[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::animation_fill_mode::SpecifiedValue[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::animation_iteration_count::SpecifiedValue[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::animation_name::SpecifiedValue[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::animation_play_state::SpecifiedValue[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::animation_timing_function::SpecifiedValue[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::background_attachment::SpecifiedValue[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::background_clip::SpecifiedValue[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::background_image::SpecifiedValue[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::background_origin::SpecifiedValue[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::background_position_x::SpecifiedValue[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::background_position_y::SpecifiedValue[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::background_repeat::SpecifiedValue[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::background_size::SpecifiedValue[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::box_shadow::SpecifiedValue[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::filter::SpecifiedValue[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::text_shadow::SpecifiedValue[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::transition_delay::SpecifiedValue[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::transition_duration::SpecifiedValue[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::transition_property::SpecifiedValue[src]

type ComputedValue = T

impl ToComputedValue for style::properties::longhands::transition_timing_function::SpecifiedValue[src]

type ComputedValue = T

impl ToComputedValue for OwnedStr[src]

type ComputedValue = OwnedStr

impl ToComputedValue for FamilyName where
    Atom: ToComputedValue<ComputedValue = Atom>,
    FontFamilyNameSyntax: ToComputedValue<ComputedValue = FontFamilyNameSyntax>, 
[src]

impl ToComputedValue for style::values::computed::font::FontFamily where
    FontFamilyList: ToComputedValue<ComputedValue = FontFamilyList>,
    bool: ToComputedValue<ComputedValue = bool>, 
[src]

impl ToComputedValue for FontFamilyList where
    Box<[SingleFontFamily]>: ToComputedValue<ComputedValue = Box<[SingleFontFamily]>>, 
[src]

impl ToComputedValue for CSSPixelLength where
    CSSFloat: ToComputedValue<ComputedValue = CSSFloat>, 
[src]

impl ToComputedValue for style::values::computed::percentage::Percentage where
    CSSFloat: ToComputedValue<ComputedValue = CSSFloat>, 
[src]

impl ToComputedValue for Path where
    FillRule: ToComputedValue<ComputedValue = FillRule>,
    SVGPathData: ToComputedValue<ComputedValue = SVGPathData>, 
[src]

type ComputedValue = Path

impl ToComputedValue for FontTag where
    u32: ToComputedValue<ComputedValue = u32>, 
[src]

type ComputedValue = FontTag

impl ToComputedValue for LineNameList where
    OwnedSlice<OwnedSlice<CustomIdent>>: ToComputedValue<ComputedValue = OwnedSlice<OwnedSlice<CustomIdent>>>,
    usize: ToComputedValue<ComputedValue = usize>,
    usize: ToComputedValue<ComputedValue = usize>, 
[src]

impl ToComputedValue for PaintWorklet where
    Atom: ToComputedValue<ComputedValue = Atom>, 
[src]

impl ToComputedValue for Angle[src]

type ComputedValue = ComputedAngle

impl ToComputedValue for BackgroundRepeat where
    BackgroundRepeatKeyword: ToComputedValue<ComputedValue = BackgroundRepeatKeyword>,
    BackgroundRepeatKeyword: ToComputedValue<ComputedValue = BackgroundRepeatKeyword>, 
[src]

impl ToComputedValue for BorderImageRepeat where
    BorderImageRepeatKeyword: ToComputedValue<ComputedValue = BorderImageRepeatKeyword>,
    BorderImageRepeatKeyword: ToComputedValue<ComputedValue = BorderImageRepeatKeyword>, 
[src]

impl ToComputedValue for AnimationName where
    Option<KeyframesName>: ToComputedValue<ComputedValue = Option<KeyframesName>>, 
[src]

impl ToComputedValue for Contain where
    u8: ToComputedValue<ComputedValue = u8>, 
[src]

type ComputedValue = Contain

impl ToComputedValue for Display where
    u16: ToComputedValue<ComputedValue = u16>, 
[src]

type ComputedValue = Display

impl ToComputedValue for ScrollSnapAlign where
    ScrollSnapAlignKeyword: ToComputedValue<ComputedValue = ScrollSnapAlignKeyword>,
    ScrollSnapAlignKeyword: ToComputedValue<ComputedValue = ScrollSnapAlignKeyword>, 
[src]

impl ToComputedValue for ScrollSnapType where
    ScrollSnapAxis: ToComputedValue<ComputedValue = ScrollSnapAxis>,
    ScrollSnapStrictness: ToComputedValue<ComputedValue = ScrollSnapStrictness>, 
[src]

impl ToComputedValue for TouchAction where
    u8: ToComputedValue<ComputedValue = u8>, 
[src]

impl ToComputedValue for WillChange where
    OwnedSlice<CustomIdent>: ToComputedValue<ComputedValue = OwnedSlice<CustomIdent>>,
    WillChangeBits: ToComputedValue<ComputedValue = WillChangeBits>, 
[src]

impl ToComputedValue for WillChangeBits where
    u8: ToComputedValue<ComputedValue = u8>, 
[src]

impl ToComputedValue for ColorPropertyValue[src]

type ComputedValue = RGBA

impl ToComputedValue for MozFontSmoothingBackgroundColor[src]

type ComputedValue = RGBA

impl ToComputedValue for NonNegativeFactor[src]

impl ToComputedValue for ZeroToOneFactor[src]

impl ToComputedValue for FontSynthesis where
    bool: ToComputedValue<ComputedValue = bool>,
    bool: ToComputedValue<ComputedValue = bool>, 
[src]

impl ToComputedValue for KeywordInfo where
    FontSizeKeyword: ToComputedValue<ComputedValue = FontSizeKeyword>,
    f32: ToComputedValue<ComputedValue = f32>,
    CSSPixelLength: ToComputedValue<ComputedValue = CSSPixelLength>, 
[src]

impl ToComputedValue for MozScriptMinSize[src]

impl ToComputedValue for MozScriptSizeMultiplier where
    f32: ToComputedValue<ComputedValue = f32>, 
[src]

impl ToComputedValue for XLang where
    Atom: ToComputedValue<ComputedValue = Atom>, 
[src]

type ComputedValue = XLang

impl ToComputedValue for XTextZoom where
    bool: ToComputedValue<ComputedValue = bool>, 
[src]

impl ToComputedValue for QuoteList where
    ArcSlice<QuotePair>: ToComputedValue<ComputedValue = ArcSlice<QuotePair>>, 
[src]

impl ToComputedValue for QuotePair where
    OwnedStr: ToComputedValue<ComputedValue = OwnedStr>,
    OwnedStr: ToComputedValue<ComputedValue = OwnedStr>, 
[src]

impl ToComputedValue for OffsetRotate[src]

impl ToComputedValue for style::values::specified::percentage::Percentage[src]

impl ToComputedValue for GridAutoFlow where
    u8: ToComputedValue<ComputedValue = u8>, 
[src]

impl ToComputedValue for MasonryAutoFlow where
    MasonryPlacement: ToComputedValue<ComputedValue = MasonryPlacement>,
    MasonryItemOrder: ToComputedValue<ComputedValue = MasonryItemOrder>, 
[src]

impl ToComputedValue for NamedArea where
    Atom: ToComputedValue<ComputedValue = Atom>,
    UnsignedRange: ToComputedValue<ComputedValue = UnsignedRange>,
    UnsignedRange: ToComputedValue<ComputedValue = UnsignedRange>, 
[src]

impl ToComputedValue for TemplateAreas where
    OwnedSlice<NamedArea>: ToComputedValue<ComputedValue = OwnedSlice<NamedArea>>,
    OwnedSlice<OwnedStr>: ToComputedValue<ComputedValue = OwnedSlice<OwnedStr>>,
    u32: ToComputedValue<ComputedValue = u32>, 
[src]

impl ToComputedValue for TemplateAreasArc where
    Arc<TemplateAreas>: ToComputedValue<ComputedValue = Arc<TemplateAreas>>, 
[src]

impl ToComputedValue for UnsignedRange where
    u32: ToComputedValue<ComputedValue = u32>,
    u32: ToComputedValue<ComputedValue = u32>, 
[src]

impl ToComputedValue for Attr where
    Prefix: ToComputedValue<ComputedValue = Prefix>,
    Namespace: ToComputedValue<ComputedValue = Namespace>,
    Atom: ToComputedValue<ComputedValue = Atom>, 
[src]

type ComputedValue = Attr

impl ToComputedValue for Integer[src]

type ComputedValue = i32

impl ToComputedValue for Number[src]

impl ToComputedValue for Opacity[src]

impl ToComputedValue for ContextPropertyBits where
    u8: ToComputedValue<ComputedValue = u8>, 
[src]

impl ToComputedValue for MozContextProperties where
    ArcSlice<CustomIdent>: ToComputedValue<ComputedValue = ArcSlice<CustomIdent>>,
    ContextPropertyBits: ToComputedValue<ComputedValue = ContextPropertyBits>, 
[src]

impl ToComputedValue for SVGPaintOrder where
    u8: ToComputedValue<ComputedValue = u8>, 
[src]

impl ToComputedValue for ArcFlag where
    bool: ToComputedValue<ComputedValue = bool>, 
[src]

type ComputedValue = ArcFlag

impl ToComputedValue for CoordPair where
    CSSFloat: ToComputedValue<ComputedValue = CSSFloat>,
    CSSFloat: ToComputedValue<ComputedValue = CSSFloat>, 
[src]

impl ToComputedValue for SVGPathData where
    ArcSlice<PathCommand>: ToComputedValue<ComputedValue = ArcSlice<PathCommand>>, 
[src]

impl ToComputedValue for TextDecorationLine where
    u8: ToComputedValue<ComputedValue = u8>, 
[src]

impl ToComputedValue for TextEmphasisPosition where
    TextEmphasisHorizontalWritingModeValue: ToComputedValue<ComputedValue = TextEmphasisHorizontalWritingModeValue>,
    TextEmphasisVerticalWritingModeValue: ToComputedValue<ComputedValue = TextEmphasisVerticalWritingModeValue>, 
[src]

impl ToComputedValue for TextOverflow[src]

impl ToComputedValue for TextTransform where
    TextTransformCase: ToComputedValue<ComputedValue = TextTransformCase>,
    TextTransformOther: ToComputedValue<ComputedValue = TextTransformOther>, 
[src]

impl ToComputedValue for TextTransformOther where
    u8: ToComputedValue<ComputedValue = u8>, 
[src]

impl ToComputedValue for TextUnderlinePosition where
    u8: ToComputedValue<ComputedValue = u8>, 
[src]

impl ToComputedValue for Time[src]

type ComputedValue = ComputedTime

impl ToComputedValue for MozForceBrokenImageIcon where
    bool: ToComputedValue<ComputedValue = bool>, 
[src]

impl ToComputedValue for Auto[src]

type ComputedValue = Auto

impl ToComputedValue for CustomIdent where
    Atom: ToComputedValue<ComputedValue = Atom>, 
[src]

impl ToComputedValue for None_[src]

type ComputedValue = None_

impl ToComputedValue for SpecifiedUrl[src]

impl ToComputedValue for Atom[src]

type ComputedValue = Atom

impl ToComputedValue for Namespace[src]

type ComputedValue = Namespace

impl ToComputedValue for Prefix[src]

type ComputedValue = Prefix

impl ToComputedValue for BoxShadow[src]

impl ToComputedValue for SimpleShadow[src]

impl ToComputedValue for SpecifiedFontStyle[src]

impl ToComputedValue for LetterSpacing[src]

type ComputedValue = LetterSpacing

impl ToComputedValue for LineHeight[src]

impl ToComputedValue for WordSpacing[src]

type ComputedValue = WordSpacing

impl<A, B> ToComputedValue for Either<A, B> where
    A: ToComputedValue,
    B: ToComputedValue
[src]

impl<Angle> ToComputedValue for GenericOffsetPath<Angle> where
    Angle: ToComputedValue
[src]

impl<Angle> ToComputedValue for RayFunction<Angle> where
    Angle: ToComputedValue
[src]

impl<Angle, NonNegativeFactor, ZeroToOneFactor, Length, Shadow, U> ToComputedValue for GenericFilter<Angle, NonNegativeFactor, ZeroToOneFactor, Length, Shadow, U> where
    Angle: ToComputedValue,
    NonNegativeFactor: ToComputedValue,
    ZeroToOneFactor: ToComputedValue,
    Length: ToComputedValue,
    Shadow: ToComputedValue,
    U: ToComputedValue
[src]

impl<Angle, Number, Length, Integer, LengthPercentage> ToComputedValue for GenericTransformOperation<Angle, Number, Length, Integer, LengthPercentage> where
    Angle: Zero,
    LengthPercentage: Zero,
    Number: PartialEq,
    <Angle as ToComputedValue>::ComputedValue: Zero,
    <LengthPercentage as ToComputedValue>::ComputedValue: Zero,
    <Number as ToComputedValue>::ComputedValue: PartialEq,
    Angle: ToComputedValue,
    Number: ToComputedValue,
    Length: ToComputedValue,
    Integer: ToComputedValue,
    LengthPercentage: ToComputedValue
[src]

impl<BasicShape, I> ToComputedValue for GenericShapeOutside<BasicShape, I> where
    BasicShape: ToComputedValue,
    I: ToComputedValue
[src]

impl<BasicShape, U> ToComputedValue for GenericClipPath<BasicShape, U> where
    BasicShape: ToComputedValue,
    U: ToComputedValue
[src]

impl<C> ToComputedValue for GenericColorOrAuto<C> where
    C: ToComputedValue
[src]

impl<C> ToComputedValue for GenericSVGPaintFallback<C> where
    C: ToComputedValue
[src]

impl<C, U> ToComputedValue for GenericSVGPaintKind<C, U> where
    C: ToComputedValue,
    U: ToComputedValue
[src]

impl<Color> ToComputedValue for GenericScrollbarColor<Color> where
    Color: ToComputedValue
[src]

impl<Color, T> ToComputedValue for GenericGradientItem<Color, T> where
    Color: ToComputedValue,
    T: ToComputedValue
[src]

impl<Color, T> ToComputedValue for ColorStop<Color, T> where
    Color: ToComputedValue,
    T: ToComputedValue
[src]

impl<Color, Url> ToComputedValue for GenericSVGPaint<Color, Url> where
    Color: ToComputedValue,
    Url: ToComputedValue
[src]

impl<G, MozImageRect, ImageUrl> ToComputedValue for GenericImage<G, MozImageRect, ImageUrl> where
    G: ToComputedValue,
    MozImageRect: ToComputedValue,
    ImageUrl: ToComputedValue
[src]

impl<H, V> ToComputedValue for GenericPosition<H, V> where
    H: ToComputedValue,
    V: ToComputedValue
[src]

impl<H, V, Depth> ToComputedValue for GenericTransformOrigin<H, V, Depth> where
    H: ToComputedValue,
    V: ToComputedValue,
    Depth: ToComputedValue
[src]

impl<H, V, LengthPercentage, NonNegativeLengthPercentage> ToComputedValue for GenericBasicShape<H, V, LengthPercentage, NonNegativeLengthPercentage> where
    H: ToComputedValue,
    V: ToComputedValue,
    LengthPercentage: ToComputedValue,
    NonNegativeLengthPercentage: ToComputedValue
[src]

type ComputedValue = GenericBasicShape<<H as ToComputedValue>::ComputedValue, <V as ToComputedValue>::ComputedValue, <LengthPercentage as ToComputedValue>::ComputedValue, <NonNegativeLengthPercentage as ToComputedValue>::ComputedValue>

impl<H, V, NonNegativeLengthPercentage> ToComputedValue for Circle<H, V, NonNegativeLengthPercentage> where
    H: ToComputedValue,
    V: ToComputedValue,
    NonNegativeLengthPercentage: ToComputedValue
[src]

type ComputedValue = Circle<<H as ToComputedValue>::ComputedValue, <V as ToComputedValue>::ComputedValue, <NonNegativeLengthPercentage as ToComputedValue>::ComputedValue>

impl<H, V, NonNegativeLengthPercentage> ToComputedValue for Ellipse<H, V, NonNegativeLengthPercentage> where
    H: ToComputedValue,
    V: ToComputedValue,
    NonNegativeLengthPercentage: ToComputedValue
[src]

type ComputedValue = Ellipse<<H as ToComputedValue>::ComputedValue, <V as ToComputedValue>::ComputedValue, <NonNegativeLengthPercentage as ToComputedValue>::ComputedValue>

impl<I> ToComputedValue for GenericZIndex<I> where
    I: ToComputedValue
[src]

impl<I> ToComputedValue for GenericCounterIncrement<I> where
    I: ToComputedValue
[src]

impl<I> ToComputedValue for GenericCounterSetOrReset<I> where
    I: ToComputedValue
[src]

impl<I> ToComputedValue for GenericCounters<I> where
    I: ToComputedValue
[src]

impl<Image> ToComputedValue for GenericCursor<Image> where
    Image: ToComputedValue
[src]

impl<ImageUrl> ToComputedValue for GenericContent<ImageUrl> where
    ImageUrl: ToComputedValue
[src]

impl<ImageUrl> ToComputedValue for GenericContentItem<ImageUrl> where
    ImageUrl: ToComputedValue
[src]

impl<ImageUrl, Number> ToComputedValue for GenericCursorImage<ImageUrl, Number> where
    ImageUrl: ToComputedValue,
    Number: ToComputedValue
[src]

impl<Integer> ToComputedValue for RepeatCount<Integer> where
    Integer: ToComputedValue
[src]

impl<Integer> ToComputedValue for GenericCounterPair<Integer> where
    Integer: ToComputedValue
[src]

impl<Integer> ToComputedValue for FeatureTagValue<Integer> where
    Integer: ToComputedValue
[src]

impl<Integer> ToComputedValue for GenericGridLine<Integer> where
    Integer: ToComputedValue
[src]

impl<Integer, Number> ToComputedValue for TimingFunction<Integer, Number> where
    Integer: ToComputedValue,
    Number: ToComputedValue
[src]

impl<L> ToComputedValue for GenericTrackBreadth<L> where
    L: ToComputedValue
[src]

impl<L> ToComputedValue for GenericTrackSize<L> where
    L: ToComputedValue
[src]

impl<L> ToComputedValue for GenericSVGLength<L> where
    L: ToComputedValue
[src]

impl<L> ToComputedValue for GenericSVGStrokeDashArray<L> where
    L: ToComputedValue
[src]

impl<L> ToComputedValue for GenericTextDecorationLength<L> where
    L: ToComputedValue
[src]

impl<L> ToComputedValue for BorderSpacing<L> where
    L: ToComputedValue
[src]

impl<L> ToComputedValue for GenericBorderCornerRadius<L> where
    L: ToComputedValue
[src]

impl<L> ToComputedValue for style::values::generics::size::Size2D<L> where
    L: ToComputedValue
[src]

impl<L, I> ToComputedValue for GenericGridTemplateComponent<L, I> where
    L: ToComputedValue,
    I: ToComputedValue,
    Box<GenericTrackList<L, I>>: ToComputedValue<ComputedValue = Box<GenericTrackList<<L as ToComputedValue>::ComputedValue, <I as ToComputedValue>::ComputedValue>>>, 
[src]

impl<L, I> ToComputedValue for GenericTrackRepeat<L, I> where
    L: ToComputedValue,
    I: ToComputedValue
[src]

impl<L, N> ToComputedValue for GenericLengthOrNumber<L, N> where
    L: ToComputedValue,
    N: ToComputedValue
[src]

impl<LP, N> ToComputedValue for GenericBorderImageSideWidth<LP, N> where
    LP: ToComputedValue,
    N: ToComputedValue
[src]

impl<LengthOrAuto> ToComputedValue for GenericClipRect<LengthOrAuto> where
    LengthOrAuto: ToComputedValue
[src]

impl<LengthPercent> ToComputedValue for GenericBackgroundSize<LengthPercent> where
    LengthPercent: ToComputedValue
[src]

impl<LengthPercent> ToComputedValue for GenericLengthPercentageOrAuto<LengthPercent> where
    LengthPercent: ToComputedValue
[src]

impl<LengthPercent> ToComputedValue for GenericLengthPercentageOrNormal<LengthPercent> where
    LengthPercent: ToComputedValue
[src]

impl<LengthPercent> ToComputedValue for GenericMaxSize<LengthPercent> where
    LengthPercent: ToComputedValue
[src]

impl<LengthPercent> ToComputedValue for GenericSize<LengthPercent> where
    LengthPercent: ToComputedValue
[src]

type ComputedValue = GenericSize<<LengthPercent as ToComputedValue>::ComputedValue>

impl<LengthPercentage> ToComputedValue for GenericVerticalAlign<LengthPercentage> where
    LengthPercentage: ToComputedValue
[src]

impl<LengthPercentage> ToComputedValue for GenericPolygon<LengthPercentage> where
    LengthPercentage: ToComputedValue
[src]

type ComputedValue = GenericPolygon<<LengthPercentage as ToComputedValue>::ComputedValue>

impl<LengthPercentage> ToComputedValue for PolygonCoord<LengthPercentage> where
    LengthPercentage: ToComputedValue
[src]

type ComputedValue = PolygonCoord<<LengthPercentage as ToComputedValue>::ComputedValue>

impl<LengthPercentage> ToComputedValue for GenericBorderRadius<LengthPercentage> where
    LengthPercentage: ToComputedValue
[src]

impl<LengthPercentage, Integer> ToComputedValue for GenericTrackListValue<LengthPercentage, Integer> where
    LengthPercentage: ToComputedValue,
    Integer: ToComputedValue
[src]

impl<LengthPercentage, Integer> ToComputedValue for GenericTrackList<LengthPercentage, Integer> where
    LengthPercentage: ToComputedValue,
    Integer: ToComputedValue
[src]

impl<LengthPercentage, Length> ToComputedValue for GenericTranslate<LengthPercentage, Length> where
    LengthPercentage: Zero,
    Length: Zero,
    <LengthPercentage as ToComputedValue>::ComputedValue: Zero,
    <Length as ToComputedValue>::ComputedValue: Zero,
    LengthPercentage: ToComputedValue,
    Length: ToComputedValue
[src]

impl<LengthPercentage, NonNegativeLengthPercentage> ToComputedValue for InsetRect<LengthPercentage, NonNegativeLengthPercentage> where
    LengthPercentage: ToComputedValue,
    NonNegativeLengthPercentage: ToComputedValue
[src]

type ComputedValue = InsetRect<<LengthPercentage as ToComputedValue>::ComputedValue, <NonNegativeLengthPercentage as ToComputedValue>::ComputedValue>

impl<LineDirection, LengthPercentage, NonNegativeLength, NonNegativeLengthPercentage, Position, Angle, AngleOrPercentage, Color> ToComputedValue for GenericGradient<LineDirection, LengthPercentage, NonNegativeLength, NonNegativeLengthPercentage, Position, Angle, AngleOrPercentage, Color> where
    LineDirection: ToComputedValue,
    LengthPercentage: ToComputedValue,
    NonNegativeLength: ToComputedValue,
    NonNegativeLengthPercentage: ToComputedValue,
    Position: ToComputedValue,
    Angle: ToComputedValue,
    AngleOrPercentage: ToComputedValue,
    Color: ToComputedValue
[src]

type ComputedValue = GenericGradient<<LineDirection as ToComputedValue>::ComputedValue, <LengthPercentage as ToComputedValue>::ComputedValue, <NonNegativeLength as ToComputedValue>::ComputedValue, <NonNegativeLengthPercentage as ToComputedValue>::ComputedValue, <Position as ToComputedValue>::ComputedValue, <Angle as ToComputedValue>::ComputedValue, <AngleOrPercentage as ToComputedValue>::ComputedValue, <Color as ToComputedValue>::ComputedValue>

impl<N> ToComputedValue for PreferredRatio<N> where
    N: ToComputedValue
[src]

impl<N> ToComputedValue for GenericAspectRatio<N> where
    N: ToComputedValue
[src]

impl<N> ToComputedValue for Ratio<N> where
    N: ToComputedValue
[src]

impl<NonNegativeLength> ToComputedValue for GenericPerspective<NonNegativeLength> where
    NonNegativeLength: ToComputedValue
[src]

type ComputedValue = GenericPerspective<<NonNegativeLength as ToComputedValue>::ComputedValue>

impl<NonNegativeLength> ToComputedValue for GenericCircle<NonNegativeLength> where
    NonNegativeLength: ToComputedValue
[src]

type ComputedValue = GenericCircle<<NonNegativeLength as ToComputedValue>::ComputedValue>

impl<NonNegativeLength, NonNegativeLengthPercentage> ToComputedValue for GenericEndingShape<NonNegativeLength, NonNegativeLengthPercentage> where
    NonNegativeLength: ToComputedValue,
    NonNegativeLengthPercentage: ToComputedValue
[src]

type ComputedValue = GenericEndingShape<<NonNegativeLength as ToComputedValue>::ComputedValue, <NonNegativeLengthPercentage as ToComputedValue>::ComputedValue>

impl<NonNegativeLengthPercentage> ToComputedValue for GenericShapeRadius<NonNegativeLengthPercentage> where
    NonNegativeLengthPercentage: ToComputedValue
[src]

type ComputedValue = GenericShapeRadius<<NonNegativeLengthPercentage as ToComputedValue>::ComputedValue>

impl<NonNegativeLengthPercentage> ToComputedValue for GenericEllipse<NonNegativeLengthPercentage> where
    NonNegativeLengthPercentage: ToComputedValue
[src]

type ComputedValue = GenericEllipse<<NonNegativeLengthPercentage as ToComputedValue>::ComputedValue>

impl<Number> ToComputedValue for AnimationIterationCount<Number> where
    Number: ToComputedValue
[src]

impl<Number> ToComputedValue for GenericScale<Number> where
    Number: ToComputedValue
[src]

impl<Number> ToComputedValue for VariationValue<Number> where
    Number: ToComputedValue
[src]

impl<Number, Angle> ToComputedValue for GenericRotate<Number, Angle> where
    Number: ToComputedValue,
    Angle: ToComputedValue
[src]

impl<Number, Integer> ToComputedValue for InitialLetter<Number, Integer> where
    Number: ToComputedValue,
    Integer: ToComputedValue
[src]

impl<NumberOrPercentage> ToComputedValue for GenericBorderImageSlice<NumberOrPercentage> where
    NumberOrPercentage: ToComputedValue
[src]

impl<NumberOrPercentage, MozImageRectUrl> ToComputedValue for GenericMozImageRect<NumberOrPercentage, MozImageRectUrl> where
    NumberOrPercentage: ToComputedValue,
    MozImageRectUrl: ToComputedValue
[src]

type ComputedValue = GenericMozImageRect<<NumberOrPercentage as ToComputedValue>::ComputedValue, <MozImageRectUrl as ToComputedValue>::ComputedValue>

impl<OpacityType> ToComputedValue for GenericSVGOpacity<OpacityType> where
    OpacityType: ToComputedValue
[src]

impl<Pos> ToComputedValue for GenericPositionOrAuto<Pos> where
    Pos: ToComputedValue
[src]

impl<PositiveInteger> ToComputedValue for ColumnCount<PositiveInteger> where
    PositiveInteger: ToComputedValue
[src]

type ComputedValue = ColumnCount<<PositiveInteger as ToComputedValue>::ComputedValue>

impl<R> ToComputedValue for GenericClipRectOrAuto<R> where
    R: ToComputedValue
[src]

impl<S> ToComputedValue for GenericFlexBasis<S> where
    S: ToComputedValue
[src]

impl<S> ToComputedValue for OriginComponent<S> where
    S: Side
[src]

impl<S: Side> ToComputedValue for PositionComponent<S>[src]

impl<T> ToComputedValue for Arc<T> where
    T: ToComputedValue<ComputedValue = T>, 
[src]

type ComputedValue = Self

impl<T> ToComputedValue for ArcSlice<T> where
    T: ToComputedValue<ComputedValue = T>, 
[src]

type ComputedValue = Self

impl<T> ToComputedValue for OwnedSlice<T> where
    T: ToComputedValue
[src]

impl<T> ToComputedValue for FontSettings<T> where
    T: ToComputedValue
[src]

impl<T> ToComputedValue for GenericImplicitGridTracks<T> where
    T: ToComputedValue
[src]

impl<T> ToComputedValue for Rect<T> where
    T: ToComputedValue
[src]

impl<T> ToComputedValue for GreaterThanOrEqualToOne<T> where
    T: ToComputedValue
[src]

impl<T> ToComputedValue for NonNegative<T> where
    T: ToComputedValue
[src]

impl<T> ToComputedValue for ZeroToOne<T> where
    T: ToComputedValue
[src]

impl<T> ToComputedValue for GenericMatrix<T> where
    T: ToComputedValue
[src]

impl<T> ToComputedValue for GenericMatrix3D<T> where
    T: ToComputedValue
[src]

impl<T> ToComputedValue for GenericTransform<T> where
    T: ToComputedValue
[src]

impl<U> ToComputedValue for GenericUrlOrNone<U> where
    U: ToComputedValue
[src]

Loading content...